/**
 * eobjects.org MetaModel
 * Copyright (C) 2010 eobjects.org
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */
package org.eobjects.metamodel.data;

import java.util.List;

import org.eobjects.metamodel.query.SelectItem;
import org.eobjects.metamodel.schema.Column;

/**
 * An empty data set.
 * 
 * @author Kasper Sørensen
 */
public final class EmptyDataSet extends AbstractDataSet {

	private final SelectItem[] _selectItems;

	public EmptyDataSet(SelectItem[] selectItems) {
		_selectItems = selectItems;
	}

	public EmptyDataSet(Column[] columns) {
		_selectItems = new SelectItem[columns.length];
		for (int i = 0; i < columns.length; i++) {
			Column column = columns[i];
			_selectItems[i] = new SelectItem(column);
		}
	}

	public EmptyDataSet(List<SelectItem> selectItems) {
		_selectItems = selectItems.toArray(new SelectItem[selectItems.size()]);
	}

	@Override
	public SelectItem[] getSelectItems() {
		return _selectItems;
	}

	@Override
	public boolean next() {
		return false;
	}

	@Override
	public Row getRow() {
		return null;
	}

}
