/**
 * eobjects.org MetaModel
 * Copyright (C) 2010 eobjects.org
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */
package org.eobjects.metamodel.query.builder;

import java.util.Collection;
import java.util.Date;

import org.eobjects.metamodel.schema.Column;

/**
 * Interface for builder callbacks that "respond" to filter condition building.
 * 
 * @param <B>
 *            the builder type to return once filter has been created.
 */
public interface FilterBuilder<B> {

    public B isNull();

    public B isNotNull();

    public B in(Collection<?> values);

    public B in(Number... numbers);

    public B in(String... strings);

    public B equals(Column column);

    public B equals(Date date);

    public B equals(Number number);

    public B equals(String string);

    public B equals(Boolean bool);

    public B differentFrom(Column column);

    public B differentFrom(Date date);

    public B differentFrom(Number number);

    public B differentFrom(String string);

    public B differentFrom(Boolean bool);

    /**
     * @deprecated use {@link #greaterThan(Column)} instead
     */
    @Deprecated
    public B higherThan(Column column);

    public B greaterThan(Column column);

    /**
     * @deprecated use {@link #greaterThan(Date)} instead
     */
    @Deprecated
    public B higherThan(Date date);

    public B greaterThan(Date date);

    /**
     * @deprecated use {@link #greaterThan(Number)} instead
     */
    @Deprecated
    public B higherThan(Number number);

    public B greaterThan(Number number);

    /**
     * @deprecated use {@link #greaterThan(String)} instead
     */
    @Deprecated
    public B higherThan(String string);

    public B greaterThan(String string);

    public B lessThan(Column column);

    public B lessThan(Date date);

    public B lessThan(Number number);

    public B lessThan(String string);

    public B like(String string);
}
