/**
 * eobjects.org MetaModel
 * Copyright (C) 2010 eobjects.org
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */
package org.eobjects.metamodel.query.parser;

import org.eobjects.metamodel.DataContext;
import org.eobjects.metamodel.MetaModelException;
import org.eobjects.metamodel.query.Query;
import org.eobjects.metamodel.schema.Table;

final class FromItemParser implements QueryPartProcessor {

    private final Query _query;
    private final DataContext _dataContext;

    public FromItemParser(DataContext dataContext, Query query) {
        _dataContext = dataContext;
        _query = query;
    }

    @Override
    public void parse(String delim, String itemToken) {
        if (itemToken.indexOf('(') != -1) {
            throw new MetaModelException("Not capable of parsing FROM token: " + itemToken);
        }

        if (itemToken.indexOf(" JOIN ") != -1) {
            // TODO
            throw new MetaModelException("Not capable of parsing FROM token because JOINs are not yet supported: "
                    + itemToken);
        }

        final String[] tokens = itemToken.split(" ");
        final String alias;
        if (tokens.length == 2) {
            alias = tokens[1];
        } else if (tokens.length == 1) {
            alias = null;
        } else {
            throw new MetaModelException("Not capable of parsing FROM token: " + itemToken);
        }

        Table table = _dataContext.getTableByQualifiedLabel(tokens[0]);
        if (table == null) {
            throw new MetaModelException("Not capable of parsing FROM token: " + itemToken);
        }
        _query.from(table, alias);
    }

}
